@@ -1,3 +1,3 @@
 from spasis.spasis import create_voronoi
-from spasis.spasis import transfer_tvalue
+from spasis.spasis import transfer_val
 from spasis.spasis import binaryClassifier
\ No newline at end of file
