@@ -20,10 +20,6 @@ class create_voronoi:
         self.attribute = attribute
         
         if isinstance(boundary, str):
-            bounds = pd.concat([gpd.read_file(shp)for shp in [i for i in glob.glob(f"{boundary}/*.shp")]]).pipe(gpd.GeoDataFrame)
-            if bounds.crs == None:
-                bounds.crs = {'init': 'epsg:4326'}
-        elif not isinstance(boundary, gpd.GeoDataFrame):
             bounds = gpd.read_file(boundary)
             if bounds.crs == None:
                 bounds.crs = {'init': 'epsg:4326'}
@@ -35,17 +31,13 @@ class create_voronoi:
             raise TypeError("Expecting a string like object of gpd.Geodataframe like object for point shapefile")
         
         if isinstance(point_shape, str):
-            centr = pd.concat([gpd.read_file(shp)for shp in [i for i in glob.glob(f"{point_shape}/*.shp")]]).pipe(gpd.GeoDataFrame)
+            centr = gpd.read_file(point_shape)
             if centr.crs == None:
                 centr.crs = {'init': 'epsg:4326'}
         elif isinstance(point_shape, gpd.GeoDataFrame):
             centr = self.point_shape
             if centr.crs == None:
                 centr.crs = {'init': 'epsg:4326'}
-        elif not isinstance(point_shape, gpd.GeoDataFrame):
-            centr = gpd.read_file(point_shape)
-            if centr.crs == None:
-                centr.crs = {'init': 'epsg:4326'}
         else:
             raise TypeError("Expecting a string like object of gpd.Geodataframe like object for point shapefile")
         
